#!/bin/bash

# Location for the installed SIMBL
INSTALLED_SIMBL_LOCATION_LT9=/Library/InputManagers/SIMBL/SIMBL.bundle
INSTALLED_SIMBL_LOCATION_GE9=/Library/ScriptingAdditions/SIMBL.osax

# Relative location for the SIMBL install package
SIMBL_PACKAGE_LOCATION=SIMBL.pkg

# Checks if SIMBL is installed. Returns 1 if it is, else 0.
function isSIMBLInstalled
{
	ISSNOWLEOPARD=`echo "$(uname -a | awk '{print $3}' | cut -d'.' -f1- | tr -d '.') >= 1060" | bc`
	if [ $ISSNOWLEOPARD -eq 1 ]; then # For Snow Leopard and above
		NEEDED_SIMBL_VERSION=0.93
		INSTALLED_SIMBL_LOCATION=$INSTALLED_SIMBL_LOCATION_GE9
	else # For Leopard and below
		NEEDED_SIMBL_VERSION=0.82
		INSTALLED_SIMBL_LOCATION=$INSTALLED_SIMBL_LOCATION_LT9
	fi
	
	# Plist for the possibly installed SIMBL (without the .plist)
	INSTALLED_SIMBL_PLIST=$INSTALLED_SIMBL_LOCATION/Contents/Info

	if [ -e $INSTALLED_SIMBL_LOCATION ]; then
		# Get the bundle version from the installed SIMBL
		VERSION=`defaults read $INSTALLED_SIMBL_PLIST CFBundleShortVersionString`
		
		# Bash cannot compare floats, so we use BC
		VERSION_AS_FLOAT=`echo $VERSION | cut -d'.' -f1`.`echo $VERSION | cut -d'.' -f2- | tr -d '.'`
		ISGOOD=`echo "$VERSION_AS_FLOAT >= $NEEDED_SIMBL_VERSION" | bc`
	
		if [ $ISGOOD -eq 1 ]; then
			echo SIMBL is installed.
			return 1
		fi
	fi
	echo SIMBL is not installed or does not have the right version.
	return 0
}

# Check if SIMBL is installed (return value stored in $?)
isSIMBLInstalled
if [ $? -ne 1 ]; then
	open -W $SIMBL_PACKAGE_LOCATION
	
	# Check if it got installed
	isSIMBLInstalled
	if [ $? -ne 1 ]; then
		exit 1
	fi
fi

# If we get this far, we are ok.
exit 0